@@ -74,6 +74,7 @@ from trackme_libs import (
     trackme_register_tenant_object_summary_gen_non_persistent,
     trackme_register_tenant_object_summary_gen_persistent,
     run_splunk_search,
+    is_reachable_with_retry,
 )
 
 # import trackme licensing libs
@@ -297,13 +298,18 @@ class SplunkRemoteSearch(GeneratingCommand):
         except Exception as e:
             return False, str(e)
 
-    def select_url(self, session, splunk_url, timeout=15):
+    def select_url(self, session, splunk_url, timeout=15, retry_config=None):
         splunk_urls = splunk_url.split(",")
         unreachable_errors = []
 
         reachable_urls = []
         for url in splunk_urls:
-            reachable, error = self.is_reachable(session, url, timeout)
+            if retry_config:
+                # Use shared retry function, passing self.is_reachable as the function to use
+                reachable, error = is_reachable_with_retry(session, url, timeout, retry_config, self.is_reachable)
+            else:
+                reachable, error = self.is_reachable(session, url, timeout)
+            
             if reachable:
                 reachable_urls.append(url)
             else:
@@ -612,6 +618,15 @@ class SplunkRemoteSearch(GeneratingCommand):
                 f"timeout_search_check is not an integer, received value: {timeout_search_check}, setting to 300"
             )
 
+        # retry configuration
+        retry_config = {
+            "retry_enabled": account_dict.get("retry_enabled", "1"),
+            "retry_max_total_time": account_dict.get("retry_max_total_time", "30"),
+            "retry_initial_delay": account_dict.get("retry_initial_delay", "2"),
+            "retry_backoff_multiplier": account_dict.get("retry_backoff_multiplier", "2.0"),
+            "retry_max_attempts": account_dict.get("retry_max_attempts", "10"),
+        }
+
         # Get user's direct roles
         user_roles = self.get_user_roles()
 
@@ -719,7 +734,7 @@ class SplunkRemoteSearch(GeneratingCommand):
         else:
             # original behavior: select one working URL
             selected_url, errors = self.select_url(
-                session, splunk_url, timeout_connect_check
+                session, splunk_url, timeout_connect_check, retry_config
             )
 
             if not selected_url:
