@@ -974,6 +974,13 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
                         "status": 500,
                     }
 
+                # retry configuration (all optional)
+                retry_enabled = resp_dict.get("retry_enabled", "1")
+                retry_max_total_time = resp_dict.get("retry_max_total_time", "30")
+                retry_initial_delay = resp_dict.get("retry_initial_delay", "2")
+                retry_backoff_multiplier = resp_dict.get("retry_backoff_multiplier", "2.0")
+                retry_max_attempts = resp_dict.get("retry_max_attempts", "10")
+
         else:
             # body is not required in this endpoint, if not submitted do not describe the usage
             describe = False
@@ -991,6 +998,11 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
                         "bearer_token": "The Splunk bearer token to be used",
                         "timeout_connect_check": "Optional: The timeout in seconds for the connect health check. Defaults to 15 seconds (integer)",
                         "timeout_search_check": "Optional: The timeout in seconds for the search connection. Defaults to 300 seconds (integer)",
+                        "retry_enabled": "Optional: Enable retry with backoff (1 or 0). Defaults to 1 (enabled)",
+                        "retry_max_total_time": "Optional: Maximum total time in seconds to spend retrying. Defaults to 30 seconds (integer)",
+                        "retry_initial_delay": "Optional: Initial delay in seconds before first retry. Defaults to 2 seconds (integer)",
+                        "retry_backoff_multiplier": "Optional: Multiplier for exponential backoff. Defaults to 2.0 (float)",
+                        "retry_max_attempts": "Optional: Maximum number of retry attempts. Defaults to 10 (integer)",
                     }
                 ],
             }
@@ -1010,6 +1022,19 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
                 "timeout_connect_check": timeout_connect_check,
                 "timeout_search_check": timeout_search_check,
             }
+            
+            # Add retry configuration if provided
+            if 'retry_enabled' in locals():
+                connection_info["retry_enabled"] = retry_enabled
+            if 'retry_max_total_time' in locals():
+                connection_info["retry_max_total_time"] = retry_max_total_time
+            if 'retry_initial_delay' in locals():
+                connection_info["retry_initial_delay"] = retry_initial_delay
+            if 'retry_backoff_multiplier' in locals():
+                connection_info["retry_backoff_multiplier"] = retry_backoff_multiplier
+            if 'retry_max_attempts' in locals():
+                connection_info["retry_max_attempts"] = retry_max_attempts
+            
             response = trackme_test_remote_connectivity(connection_info)
             return {"payload": response, "status": 200}
 
